package graphs;

import java.util.Iterator;
import java.util.List;

/**
 * @version 2.0.0 Dec 2001
 */
public interface DirectedGraph extends Graph {
	
  /* 2.Methods dealing with directed edges. */
  
  /** Returns an enumeration of all directed edges (positions). */
  public Iterator directedEdges();

  /** Returns the in-degree of v. */  
  public int inDegree(Vertex v);

  /** Returns the out-degree of v. */  
  public int outDegree(Vertex v);

  /** Returns an iterator of all the incoming edges to v. */
  public Iterator inIncidentEdges(Vertex v);
  
  /** Returns an iterator of all the outgoing edges from v. */  
  public Iterator outIncidentEdges(Vertex v);
  
  /** 
   * Returns an iterator of all the vertices adjacent to v,
   * along incoming edges to v.
   */  
  public Iterator inAdjacentVertices(Vertex v);

  /**
   * Returns an iterator of all the vertices adjacent to v,
   * along outgoing edges from v.
   */
  public Iterator outAdjacentVertices(Vertex v);
  
  /** Returns the destination of the directed edge e. */
  public Vertex destination(Edge e);

  /** Returns the origin of the directed edge e. */  
  public Vertex origin(Edge e);

  
  /* 3.Methods for updating graphs */
  
  /** Reverses the direction of directed edge e. */  
  public void reverseDirection(Edge e);

  
}